pub struct DeriveOpts {
pub derive_show: bool,
pub derive_eq: bool,
pub derive_error: bool,
}Fields
derive_show: boolWhether or not to derive Show for all types
derive_eq: boolWhether or not to derive Eq for all types
derive_error: boolWhether or not to declare as Error type for types “.*error”