pub struct Opts {
pub derive: DeriveOpts,
pub ignore_stub: bool,
pub ignore_module_file: bool,
pub gen_dir: String,
pub project_name: Option<String>,
pub async_: AsyncFilterSet,
}Fields
derive: DeriveOptsignore_stub: boolWhether or not to generate stub files ; useful for update after WIT change
ignore_module_file: boolWhether or not to generate moon.mod.json ; useful if the project is part of a larger project
gen_dir: StringThe package/dir to generate the program entrance
project_name: Option<String>The project name ; or the package path prefix if the project is part of a larger project
async_: AsyncFilterSetImplementations