pub struct Opts {
pub derive_show: bool,
pub derive_eq: bool,
pub derive_error: bool,
pub ignore_stub: bool,
pub gen_dir: String,
}Fields
derive_show: boolWhether or not to derive Show for all types
derive_eq: boolWhether or not to derive Eq for all types
derive_error: boolWhether or not to declare as Error type for types “.*error”
ignore_stub: boolWhether or not to generate stub files ; useful for update after WIT change
gen_dir: StringThe package/dir to generate the program entrance
Implementations